@@ -14,10 +14,10 @@ _C = CN()
 # Dataset
 # -----------------------------------------------------------------------------
 _C.DATASET = CN()
-_C.DATASET.SOURCE = "https://github.com/pykale/data/raw/main/images/ShefPAH-179/SA_64x64.zip"
+_C.DATASET.SOURCE = "https://github.com/pykale/data/raw/main/images/ShefPAH-179/SA_64x64_v2.0.zip"
 _C.DATASET.ROOT = "../data"
 _C.DATASET.IMG_DIR = "DICOM"
-_C.DATASET.BASE_DIR = "SA_64x64"
+_C.DATASET.BASE_DIR = "SA_64x64_v2.0"
 _C.DATASET.FILE_FORAMT = "zip"
 _C.DATASET.LANDMARK_FILE = "landmarks.csv"
 _C.DATASET.MASK_DIR = "Mask"
@@ -30,18 +30,24 @@ _C.PROC.SCALE = 2
 # ---------------------------------------------------------------------------- #
 # Visualization
 # ---------------------------------------------------------------------------- #
-_C.IM_KWARGS = CN()
-_C.IM_KWARGS.cmap = "gray"
+_C.PLT_KWS = CN()
+_C.PLT_KWS.PLT = CN()
+_C.PLT_KWS.PLT.n_cols = 10
 
-_C.MARKER_KWARGS = CN()
-_C.MARKER_KWARGS.marker = "o"
-_C.MARKER_KWARGS.markerfacecolor = (1, 1, 1, 0.1)
-_C.MARKER_KWARGS.markeredgewidth = 1.5
-_C.MARKER_KWARGS.markeredgecolor = "r"
+_C.PLT_KWS.IM = CN()
+_C.PLT_KWS.IM.cmap = "gray"
 
-_C.WEIGHT_KWARGS = CN()
-_C.WEIGHT_KWARGS.markersize = 6
-_C.WEIGHT_KWARGS.alpha = 0.7
+_C.PLT_KWS.MARKER = CN()
+_C.PLT_KWS.MARKER.marker = "+"
+_C.PLT_KWS.MARKER.color = "r"
+_C.PLT_KWS.MARKER.s = 100
+_C.PLT_KWS.MARKER.linewidths = 1.5
+_C.PLT_KWS.MARKER.edgecolors = "face"
+# see https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.scatter.html for more options
+
+_C.PLT_KWS.WEIGHT = CN()
+_C.PLT_KWS.WEIGHT.markersize = 6
+_C.PLT_KWS.WEIGHT.alpha = 0.7
 
 # ---------------------------------------------------------------------------- #
 # Machine learning pipeline
@@ -54,7 +60,11 @@ _C.PIPELINE.CLASSIFIER = "linear_svc"  # ["svc", "linear_svc", "lr"]
 # ---------------------------------------------------------------------------- #
 _C.OUTPUT = CN()
 _C.OUTPUT.ROOT = "./outputs"  # output_dir
-_C.OUTPUT.SAVE_IMAGES = True
+_C.OUTPUT.SAVE_FIG = True
+
+_C.SAVE_FIG_KWARGS = CN()
+_C.SAVE_FIG_KWARGS.format = "pdf"
+_C.SAVE_FIG_KWARGS.bbox_inches = "tight"
 
 
 def get_cfg_defaults():
