@@ -39,15 +39,16 @@ def main():
     cfg.freeze()
     print(cfg)
 
-    save_images = cfg.OUTPUT.SAVE_IMAGES
-    print(f"Save Images: {save_images}")
+    save_figs = cfg.OUTPUT.SAVE_FIG
+    fig_format = cfg.SAVE_FIG_KWARGS.format
+    print(f"Save Figures: {save_figs}")
 
     # ---- initialize folder to store images ----
-    save_images_location = cfg.OUTPUT.ROOT
-    print(f"Save Images: {save_images_location}")
+    save_figures_location = cfg.OUTPUT.ROOT
+    print(f"Save Figures: {save_figures_location}")
 
-    if not os.path.exists(save_images_location):
-        os.makedirs(save_images_location)
+    if not os.path.exists(save_figures_location):
+        os.makedirs(save_figures_location)
 
     # ---- setup dataset ----
     base_dir = cfg.DATASET.BASE_DIR
@@ -55,7 +56,7 @@ def main():
     download_file_by_url(cfg.DATASET.SOURCE, cfg.DATASET.ROOT, "%s.%s" % (base_dir, file_format), file_format)
 
     img_path = os.path.join(cfg.DATASET.ROOT, base_dir, cfg.DATASET.IMG_DIR)
-    patient_dcm_list = read_dicom_dir(img_path, sort_instance=True)
+    patient_dcm_list = read_dicom_dir(img_path, sort_instance=True, sort_patient=True)
     images, patient_ids = dicom2arraylist(patient_dcm_list, return_patient_id=True)
     patient_ids = np.array(patient_ids, dtype=int)
     n_samples = len(images)
@@ -70,44 +71,62 @@ def main():
     y = landmark_df["Group"].values
     y[np.where(y != 0)] = 1  # convert to binary classification problem, i.e. no PH vs PAH
 
-    # plot the first phase of images
-    if save_images:
-        visualize.plot_multi_images(
-            [images[i][0, ...] for i in range(n_samples)],
-            marker_locs=landmarks,
-            im_kwargs=dict(cfg.IM_KWARGS),
-            marker_kwargs=dict(cfg.MARKER_KWARGS),
-            n_cols=10,
-        ).savefig(str(save_images_location) + "/0)first_phase.png")
+    # plot the first phase of images with landmarks
+    marker_names = list(landmark_df.columns[1::2])
+    markers = []
+    for marker in marker_names:
+        marker_name = marker.split(" ")
+        marker_name.pop(-1)
+        marker_name = " ".join(marker_name)
+        markers.append(marker_name)
+
+    if save_figs:
+        n_img_per_fig = 45
+        n_figures = int(n_samples / n_img_per_fig) + 1
+        for k in range(n_figures):
+            visualize.plot_multi_images(
+                [images[i][0, ...] for i in range(k * n_img_per_fig, min((k + 1) * n_img_per_fig, n_samples))],
+                marker_locs=landmarks[k * n_img_per_fig : min((k + 1) * n_img_per_fig, n_samples), :],
+                im_kwargs=dict(cfg.PLT_KWS.IM),
+                marker_cmap="Set1",
+                marker_kwargs=dict(cfg.PLT_KWS.MARKER),
+                marker_titles=markers,
+                image_titles=list(patient_ids[k * n_img_per_fig : min((k + 1) * n_img_per_fig, n_samples)]),
+                n_cols=5,
+            ).savefig(
+                str(save_figures_location) + "/0)landmark_visualization_%s_of_%s.%s" % (k + 1, n_figures, fig_format),
+                **dict(cfg.SAVE_FIG_KWARGS),
+            )
 
     # ---- data pre-processing ----
     # ----- image registration -----
     img_reg, max_dist = reg_img_stack(images.copy(), landmarks, landmarks[0])
-    if save_images:
-        visualize.plot_multi_images(
-            [img_reg[i][0, ...] for i in range(n_samples)], im_kwargs=dict(cfg.IM_KWARGS), n_cols=10
-        ).savefig(str(save_images_location) + "/1)image_registration")
+    plt_kawargs = {**{"im_kwargs": dict(cfg.PLT_KWS.IM), "image_titles": list(patient_ids)}, **dict(cfg.PLT_KWS.PLT)}
+    if save_figs:
+        visualize.plot_multi_images([img_reg[i][0, ...] for i in range(n_samples)], **plt_kawargs).savefig(
+            str(save_figures_location) + "/1)image_registration.%s" % fig_format, **dict(cfg.SAVE_FIG_KWARGS)
+        )
 
     # ----- masking -----
     img_masked = mask_img_stack(img_reg.copy(), mask)
-    if save_images:
-        visualize.plot_multi_images(
-            [img_masked[i][0, ...] for i in range(n_samples)], im_kwargs=dict(cfg.IM_KWARGS), n_cols=10
-        ).savefig(str(save_images_location) + "/2)masking")
+    if save_figs:
+        visualize.plot_multi_images([img_masked[i][0, ...] for i in range(n_samples)], **plt_kawargs).savefig(
+            str(save_figures_location) + "/2)masking.%s" % fig_format, **dict(cfg.SAVE_FIG_KWARGS)
+        )
 
     # ----- resize -----
     img_rescaled = rescale_img_stack(img_masked.copy(), scale=1 / cfg.PROC.SCALE)
-    if save_images:
-        visualize.plot_multi_images(
-            [img_rescaled[i][0, ...] for i in range(n_samples)], im_kwargs=dict(cfg.IM_KWARGS), n_cols=10
-        ).savefig(str(save_images_location) + "/3)resize")
+    if save_figs:
+        visualize.plot_multi_images([img_rescaled[i][0, ...] for i in range(n_samples)], **plt_kawargs).savefig(
+            str(save_figures_location) + "/3)resize.%s" % fig_format, **dict(cfg.SAVE_FIG_KWARGS)
+        )
 
     # ----- normalization -----
     img_norm = normalize_img_stack(img_rescaled.copy())
-    if save_images:
-        visualize.plot_multi_images(
-            [img_norm[i][0, ...] for i in range(n_samples)], im_kwargs=dict(cfg.IM_KWARGS), n_cols=10
-        ).savefig(str(save_images_location) + "/4)normalize")
+    if save_figs:
+        visualize.plot_multi_images([img_norm[i][0, ...] for i in range(n_samples)], **plt_kawargs).savefig(
+            str(save_figures_location) + "/4)normalize.%s" % fig_format, **dict(cfg.SAVE_FIG_KWARGS)
+        )
 
     # ---- evaluating machine learning pipeline ----
     x = np.concatenate([img_norm[i].reshape((1,) + img_norm[i].shape) for i in range(n_samples)], axis=0)
@@ -126,13 +145,13 @@ def main():
     weights = rescale_img_stack(weights, cfg.PROC.SCALE)  # rescale weights to original shape
     weights = mask_img_stack(weights, mask)  # masking weights
     top_weights = model_weights.select_top_weight(weights, select_ratio=0.02)  # select top 2% weights
-    if save_images:
+    if save_figs:
         visualize.plot_weights(
             top_weights[0][0],
             background_img=images[0][0],
-            im_kwargs=dict(cfg.IM_KWARGS),
-            marker_kwargs=dict(cfg.WEIGHT_KWARGS),
-        ).savefig(str(save_images_location) + "/5)weights")
+            im_kwargs=dict(cfg.PLT_KWS.IM),
+            marker_kwargs=dict(cfg.PLT_KWS.WEIGHT),
+        ).savefig(str(save_figures_location) + "/5)weights.%s" % fig_format, **dict(cfg.SAVE_FIG_KWARGS))
 
 
 if __name__ == "__main__":
